@@ -170,27 +170,31 @@ pBNB <- function(q, mu = 1, sigma = 1, nu = 1, lower.tail = TRUE, log.p = FALSE)
   if (any(mu <= 0) )  stop(paste("mu must be greater than 0 ", "\n", "")) 
   if (any(sigma <= 0) )  stop(paste("sigma must be greater than 0 ", "\n", "")) 
   if (any(nu <= 0) )  stop(paste("nu must be greater than 0 ", "\n", "")) 
-  if (any(q < 0) )  stop(paste("q must be >=0", "\n", ""))    
-  ly <- length(q)                                                       
-  FFF <- rep(0,ly)                         
-  nsigma <- rep(sigma, length = ly)
-  nmu <- rep(mu, length = ly) 
-  nnu <- rep(nu, length = ly)                                                        
-  j <- seq(along=q) 
+  if (any(q < 0) )  stop(paste("q must be >=0", "\n", ""))
+     ly <- max(length(q),length(mu),length(sigma),length(nu)) 
+      q <- rep(q, length = ly)      
+  sigma <- rep(sigma, length = ly)
+     mu <- rep(mu, length = ly)   
+     nu <- rep(nu, length = ly) 
+    FFF <- rep(0,ly)                         
+ nsigma <- rep(sigma, length = ly)
+    nmu <- rep(mu, length = ly) 
+    nnu <- rep(nu, length = ly)                                                        
+      j <- seq(along=q) 
   for (i in j)                                                          
   {                                                                 
-    y.y <- q[i]                                                   
-    nn <- nnu[i]                                                  
-    mm <- nmu[i]
+     y.y <- q[i]                                                   
+      nn <- nnu[i]                                                  
+      mm <- nmu[i]
     nsig <- nsigma[i]                                                     
-    allval <- seq(0,y.y)
-    pdfall <- dBNB(allval, mu = mm, sigma = nsig, nu = nn, log = FALSE)
-    FFF[i] <- sum(pdfall)                                             
+  allval <- seq(0,y.y)
+  pdfall <- dBNB(allval, mu = mm, sigma = nsig, nu = nn, log = FALSE)
+  FFF[i] <- sum(pdfall)                                             
   }  
-  cdf <- FFF
-  cdf <- if(lower.tail==TRUE) cdf else 1-cdf
-  cdf <- if(log.p==FALSE) cdf else log(cdf)                                                                    
-  cdf
+     cdf <- FFF
+     cdf <- if(lower.tail==TRUE) cdf else 1-cdf
+     cdf <- if(log.p==FALSE) cdf else log(cdf)                                                                    
+     cdf
 }
 #----------------------------------------------------------------------------------------
 qBNB <- function(p, mu=1, sigma=1, nu=1,  lower.tail = TRUE, log.p = FALSE,  
